@@ -77,7 +77,7 @@ has 'use_cookies' => ( is => 'rw', isa => Bool, default => sub {1} );
 
 #use LWP::Debug qw(+);
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 # shortcut
 my $UTILS = 'Dezi::Utils';
@@ -94,7 +94,7 @@ Dezi::Aggregator::Spider - web aggregator
  my $spider = Dezi::Aggregator::Spider->new(
      indexer => Dezi::Indexer->new
  );
- 
+
  $spider->indexer->start;
  $spider->crawl( 'http://swish-e.org/' );
  $spider->indexer->finish;
@@ -153,7 +153,7 @@ need to be fetched.
 
 =item ua I<lwp_useragent>
 
-Get/set the Dezi::Aggregagor::Spider::UA object.
+Get/set the Dezi::Aggregator::Spider::UA object.
 
 =item max_depth I<n>
 
@@ -173,7 +173,7 @@ next server, if any.  The default is to not limit by time.
 This optional key sets the max number of files to spider before aborting.
 The default is to not limit by number of files.  This is the number of requests
 made to the remote server, not the total number of files to index (see C<max_indexed>).
-This count is displayted at the end of indexing as C<Unique URLs>.
+This count is displayed at the end of indexing as C<Unique URLs>.
 
 This feature can (and perhaps should) be use when spidering a web site where dynamic
 content may generate unique URLs to prevent run-away spidering.
@@ -229,7 +229,7 @@ Number of seconds to wait before skipping manual prompt for username/password.
 
 =item credentials I<user:pass>
 
-String with C<username>:C<password> pair to be used when prompted by 
+String with C<username>:C<password> pair to be used when prompted by
 the server.
 
 =item follow_redirects I<1|0>
@@ -711,7 +711,7 @@ sub get_doc {
 
 Called internally when the server returns a 401 or 403 response.
 Will attempt to determine the correct credentials for I<uri>
-based on the previous attempt in I<response> and what you 
+based on the previous attempt in I<response> and what you
 have configured in B<credentials>, B<authn_callback> or when
 manually prompted.
 
@@ -1040,7 +1040,7 @@ sub looks_like_sitemap {
 =head2 crawl( I<uri> )
 
 Implements the required crawl() method. Recursively fetches I<uri>
-and its child links to a depth set in max_depth(). 
+and its child links to a depth set in max_depth().
 
 Will quit after max_files() unless max_files==0.
 
@@ -1118,7 +1118,7 @@ Peter Karman, E<lt>perl@peknet.comE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
 I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -1157,10 +1157,10 @@ L<http://search.cpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 by Peter Karman
+Copyright 2008-2015 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
