@@ -32,6 +32,15 @@ Dezi::Test::Doc - test Document class for Dezi::Test::Result
 
 =head1 SYNOPSIS
 
+    use Dezi::Test::Doc;
+
+    my %doc;  # holds all the parsed text, keyed by field name
+    ... construct %doc hash ...
+    my $test_doc = Dezi::Test::Doc->new( %doc );
+
+    print $test_doc->swishtitle, "\n";
+    print $test_doc->swishdescription, "\n";
+
 =head1 METHODS
 
 =head2 SWISH_DOC_PROP_MAP
@@ -40,10 +49,16 @@ All attributes defined in L<SWISH::3> SWISH_DOC_PROP_MAP hash.
 
 =head2 swishdefault
 
+A Metaname that is used by Swish-e if no other name is specified.
+
 =head2 swishtitle
 
+Document title.
+
 =head2 swishdescription
 
+Description of document.
+
 =head2 uri
 
 Alias for swishdocpath.
@@ -59,7 +74,7 @@ Peter Karman, E<lt>karpet@dezi.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi-app at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -104,10 +119,10 @@ L<https://metacpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 by Peter Karman
+Copyright 2015 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the terms of the GPL v2 or later.
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
